@@ -23,7 +23,7 @@ const route_dir="/app/routes";
 //const global_dir="/app/global";
 
 
-module.exports=function(db,config,validator,jvm){
+module.exports=function(db,config,validator,jvm,manifest){
     var app = express();
     //console.log(validate_model);
 
@@ -73,17 +73,35 @@ module.exports=function(db,config,validator,jvm){
     }*/
 
     app.use(function(req,res,next){
-         console.log("client request pid "+process.pid);
+         //console.log("client request pid "+process.pid +" app name " + app_name);
          req._r=db;
          req._config=config;
          req._validator=validator;
          req._jvm=jvm;
 
+         var urls = req.url.split("/");
+         console.log(req.url);
+         if(urls.length>=2){
+            if(urls[1]=="api"){
+                var re_url=work_dir+route_dir+"/"+urls[2]+".routes.js";
+                var nurl="";
+                for(var i=3;i<urls.length;i++){
+                        nurl=nurl+"/"+urls[i];
+                }
+                if(urls.length==3){
+                    nurl=nurl+"/";
+                }
+                require(re_url)(app);
+                req.url=nurl;
+            }
+         }
 
-       
+            
          next();
     });
 
+
+
     require('./iReport')(app);
     require('./oauth/oauth.routes')(app);
 
@@ -93,7 +111,7 @@ module.exports=function(db,config,validator,jvm){
     app.set('view engine','jade');
 
     //config routes
-    var routes = fs.readdirSync(work_dir+route_dir);
+    /*var routes = fs.readdirSync(work_dir+route_dir);
     for (var i in routes){
         if(routes[i].endsWith(".routes.js")){
             var r = route_dir + '/' + routes[i];
@@ -101,7 +119,7 @@ module.exports=function(db,config,validator,jvm){
             require(work_dir+r)(app);
             console.log("nylon start route :: "+r);
         }
-    }
+    }*/
 
     
 
@@ -114,5 +132,11 @@ module.exports=function(db,config,validator,jvm){
 
     //config static
     app.use(express.static(work_dir+'/public'));
+
+    app.use(function(req, res) {
+      var url = req.url;
+      
+      res.sendFile(work_dir+'/public/index.html',404);
+    });
     return app;
 }
\ No newline at end of file
